@@ -1,6 +1,6 @@
 package Net::SFTP::Foreign::Constants;
 
-our $VERSION = '1.52';
+our $VERSION = '1.63_05';
 
 use strict;
 use warnings;
@@ -117,6 +117,8 @@ BEGIN {
                       SFTP_ERR_REMOTE_STATVFS_FAILED => 48,
                       SFTP_ERR_REMOTE_FSTATVFS_FAILED => 49,
 		      SFTP_ERR_PASSWORD_AUTHENTICATION_FAILED => 50,
+                      SFTP_ERR_REMOTE_HARDLINK_FAILED => 51,
+		      SFTP_ERR_LOCAL_RENAME_FAILED => 52,
                     );
 
     for my $key (keys %constants) {
@@ -215,8 +217,9 @@ C<SFTP_ERR_REMOTE_READDIR_FAILED>, C<SFTP_ERR_REMOTE_READ_FAILED>,
 C<SFTP_ERR_REMOTE_REALPATH_FAILED>, C<SFTP_ERR_REMOTE_REMOVE_FAILED>,
 C<SFTP_ERR_REMOTE_RENAME_FAILED>, C<SFTP_ERR_REMOTE_RMDIR_FAILED>,
 C<SFTP_ERR_REMOTE_READLINK_FAILED>, C<SFTP_ERR_REMOTE_SYMLINK_FAILED>,
-C<SFTP_ERR_REMOTE_SETSTAT_FAILED>, C<SFTP_ERR_REMOTE_STAT_FAILED> and
-C<SFTP_ERR_REMOTE_WRITE_FAILED>.
+C<SFTP_ERR_REMOTE_SETSTAT_FAILED>, C<SFTP_ERR_REMOTE_STAT_FAILED>,
+C<SFTP_ERR_REMOTE_WRITE_FAILED> and
+C<SFTP_ERR_REMOTE_HARDLINK_FAILED>.
 
 Note: these constants are not defined on the SFTP draft.
 
